
# Slot: diagnosis




URI: [ks:diagnosis](https://w3id.org/linkml/tests/kitchen_sink/diagnosis)


## Domain and Range

None &#8594;  <sub>0..1</sub> [DiagnosisConcept](DiagnosisConcept.md)

## Parents


## Children


## Used by

 * [MedicalEvent](MedicalEvent.md)
